@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -6,9 +6,10 @@
 #define DBUSLOCKAGENT_H
 
 #include <QObject>
+#include <QDBusContext>
 
 class SessionBaseModel;
-class DBusLockAgent : public QObject
+class DBusLockAgent : public QObject, protected QDBusContext
 {
     Q_OBJECT
 public:
@@ -20,6 +21,14 @@ public:
     void ShowAuth(bool active);
     void Suspend(bool enable);
     void Hibernate(bool enable);
+    bool Visible() const;
+
+private:
+    bool isUpdating() const;
+
+    void getPathByPid(quint32 pid);
+    void getPPidByPid(quint32 pid);
+    void getCallerBySender();
 
 private:
     SessionBaseModel *m_model;
