@@ -11,7 +11,7 @@
     </message>
     <message numerus="yes">
         <source>Verification failed, %n chances left</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>Ověření se nezdařilo, zbývá %n pokus</numerusform><numerusform>Ověření se nezdařilo, zbývají %n pokusy</numerusform><numerusform>Ověření se nezdařilo, zbývá %n pokusů</numerusform><numerusform>Ověření se nezdařilo, zbývají %n pokusy</numerusform></translation>
     </message>
     <message>
         <source>Verification failed, only one chance left</source>
@@ -42,7 +42,7 @@
     </message>
     <message numerus="yes">
         <source>Verification failed, %n chances left</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>Ověření se nezdařilo, zbývá %n pokus</numerusform><numerusform>Ověření se nezdařilo, zbývají %n pokusy</numerusform><numerusform>Ověření se nezdařilo, zbývá %n pokusů</numerusform><numerusform>Ověření se nezdařilo, zbývají %n pokusy</numerusform></translation>
     </message>
     <message>
         <source>Verification failed, only one chance left</source>
@@ -57,7 +57,7 @@
     <name>AuthIris</name>
     <message>
         <source>Iris ID</source>
-        <translation>Identifikace duhovkou</translation>
+        <translation>Identifikace oční duhovkou</translation>
     </message>
     <message>
         <source>Verification successful</source>
@@ -65,7 +65,7 @@
     </message>
     <message numerus="yes">
         <source>Verification failed, %n chances left</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>Ověření se nezdařilo – zbývá %d pokus</numerusform><numerusform>Ověření se nezdařilo – zbývají %n pokusy</numerusform><numerusform>Ověření se nezdařilo – zbývá %d pokusů</numerusform><numerusform>Ověření se nezdařilo – zbývají %n pokusy</numerusform></translation>
     </message>
     <message>
         <source>Verification failed, only one chance left</source>
@@ -80,6 +80,25 @@
         <translation>Identifikace duhovkou uzamčena – použijte heslo</translation>
     </message>
 </context>
+<context>
+    <name>AuthPasskey</name>
+    <message>
+        <source>Please plug in the security key</source>
+        <translation>Připojte bezpečnostní klíč</translation>
+    </message>
+    <message>
+        <source>Verification successful</source>
+        <translation>Úspěšně ověřeno</translation>
+    </message>
+    <message>
+        <source>Verification failed</source>
+        <translation>Ověření se nezdařilo</translation>
+    </message>
+    <message>
+        <source>Identifying the security key</source>
+        <translation>Bezpečnostní klíč je identifikován</translation>
+    </message>
+</context>
 <context>
     <name>AuthPassword</name>
     <message>
@@ -88,7 +107,7 @@
     </message>
     <message numerus="yes">
         <source>Verification failed, %n chances left</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>Ověření se nezdařilo – zbývá %n pokus</numerusform><numerusform>Ověření se nezdařilo – zbývají %n pokusy</numerusform><numerusform>Ověření se nezdařilo – zbývá %n pokusů</numerusform><numerusform>Ověření se nezdařilo – zbývají %n pokusy</numerusform></translation>
     </message>
     <message>
         <source>Verification failed, only one chance left</source>
@@ -108,7 +127,7 @@
     </message>
     <message numerus="yes">
         <source>Please try again %n minutes later</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>Prosím, zkuste znovu za %n minutu</numerusform><numerusform>Prosím, zkuste znovu za %n minuty</numerusform><numerusform>Prosím, zkuste znovu za %n minut</numerusform><numerusform>Prosím, zkuste znovu za %n minuty</numerusform></translation>
     </message>
     <message>
         <source>Reset Password</source>
@@ -127,7 +146,7 @@
     </message>
     <message numerus="yes">
         <source>Please try again %n minutes later</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>Prosím, zkuste znovu za %n minutu</numerusform><numerusform>Prosím, zkuste znovu za %n minuty</numerusform><numerusform>Prosím, zkuste znovu za %n minut</numerusform><numerusform>Prosím, zkuste znovu za %n minuty</numerusform></translation>
     </message>
     <message>
         <source>Reset Password</source>
@@ -146,7 +165,7 @@
     </message>
     <message numerus="yes">
         <source>Verification failed, %n chances left</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>Ověření se nezdařilo – zbývá %d pokus</numerusform><numerusform>Ověření se nezdařilo – zbývají %n pokusy</numerusform><numerusform>Ověření se nezdařilo – zbývá %d pokusů</numerusform><numerusform>Ověření se nezdařilo – zbývají %n pokusy</numerusform></translation>
     </message>
     <message>
         <source>Verification failed, only one chance left</source>
@@ -166,7 +185,7 @@
     </message>
     <message numerus="yes">
         <source>Please try again %n minute(s) later</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>Prosím, zkuste znovu za %n minutu</numerusform><numerusform>Prosím, zkuste znovu za %n minuty</numerusform><numerusform>Prosím, zkuste znovu za %n minut</numerusform><numerusform>Prosím, zkuste znovu za %n minuty</numerusform></translation>
     </message>
     <message>
         <source>Please try again 1 minute later</source>
@@ -174,7 +193,7 @@
     </message>
     <message numerus="yes">
         <source>Please try again %n minutes later</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>Prosím, zkuste znovu za %n minutu</numerusform><numerusform>Prosím, zkuste znovu za %n minuty</numerusform><numerusform>Prosím, zkuste znovu za %n minut</numerusform><numerusform>Prosím, zkuste znovu za %n minuty</numerusform></translation>
     </message>
 </context>
 <context>
@@ -185,82 +204,27 @@
     </message>
     <message numerus="yes">
         <source>Your password will expire in %n days, please change it timely</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>Platnost vašeho hesla skončí za %n den, prosíme změňte si ho zavčas</numerusform><numerusform>Platnost vašeho hesla skončí za %n dny, prosíme změňte si ho zavčas</numerusform><numerusform>Platnost vašeho hesla skončí za %n dnů, prosíme změňte si ho zavčas</numerusform><numerusform>Platnost vašeho hesla skončí za %n dny, prosíme změňte si ho zavčas</numerusform></translation>
     </message>
     <message>
-        <source>Your password has expired. Please contact the administrator to change it.</source>
-        <translation type="unfinished"/>
+        <source>Password expired, please change</source>
+        <translation>Platnost hesla skončila – prosím změňte si ho</translation>
     </message>
     <message>
-        <source>Your password has expired. Please change it.</source>
-        <translation type="unfinished"/>
+        <source>Your password has expired. Please contact the administrator to change it</source>
+        <translation>Platnost vašeho hesla vypršela. Kontaktujte prosím správce a změňte si ho.</translation>
+    </message>
+    <message>
+        <source>Terminal locked, please contact administrator</source>
+        <translation>Terminál uzamčen – obraťte se na správce</translation>
     </message>
 </context>
 <context>
-    <name>ChangePasswordWidget</name>
+    <name>DeepinAuthFramework</name>
     <message>
-        <source>Your password has expired. Please change it and log in again.</source>
+        <source>Wrong Password</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Save</source>
-        <translation>Uložit</translation>
-    </message>
-    <message>
-        <source>Old password</source>
-        <translation>Staré heslo</translation>
-    </message>
-    <message>
-        <source>New password</source>
-        <translation>Nové heslo</translation>
-    </message>
-    <message>
-        <source>Repeat new password</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Password hint (Optional)</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Passwords do not match</source>
-        <translation>Zadání hesla se neshodují</translation>
-    </message>
-    <message>
-        <source>The hint is visible to all users. Do not include the password here.</source>
-        <translation>Nápověda je viditelná všem uživatelům. Nepište sem heslo.</translation>
-    </message>
-    <message>
-        <source>New password should differ from the current one</source>
-        <translation>Nové heslo by nemělo být stejné jako to původní</translation>
-    </message>
-    <message>
-        <source>Password changed</source>
-        <translation>Heslo změněno</translation>
-    </message>
-    <message>
-        <source>Wrong password</source>
-        <translation>Chybné heslo</translation>
-    </message>
-</context>
-<context>
-    <name>ControlWidget</name>
-    <message>
-        <source>Desktop Environment and Display Protocol</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Keyboard Layout</source>
-        <translation>Rozvržení klávesnice</translation>
-    </message>
-    <message>
-        <source>Switch User</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Power</source>
-        <translation>Napájení</translation>
-    </message>
 </context>
 <context>
     <name>GreeterWorker</name>
@@ -279,6 +243,17 @@
         <source>Cancel</source>
         <translation>Zrušit</translation>
     </message>
+    <message>
+        <source>The reason of inhibit.</source>
+        <translation>Důvod inhibováni.</translation>
+    </message>
+</context>
+<context>
+    <name>LighterGreeter</name>
+    <message>
+        <source>Standard Mode</source>
+        <translation>Standardní režim</translation>
+    </message>
 </context>
 <context>
     <name>LockContent</name>
@@ -318,69 +293,10 @@
     </message>
 </context>
 <context>
-    <name>PasswordLevelWidget</name>
+    <name>SessionWidget</name>
     <message>
-        <source>Weak</source>
-        <translation>Slabé</translation>
-    </message>
-    <message>
-        <source>Medium</source>
-        <translation>Střední</translation>
-    </message>
-    <message>
-        <source>Strong</source>
-        <translation>Silné</translation>
-    </message>
-</context>
-<context>
-    <name>PwqualityManager</name>
-    <message>
-        <source>Password cannot be empty</source>
-        <translation>Heslo nemůže být prázdné</translation>
-    </message>
-    <message>
-        <source>Password must have at least %1 characters</source>
-        <translation>Je třeba, aby heslo mělo délku alespoň %1 znaků</translation>
-    </message>
-    <message>
-        <source>Password must be no more than %1 characters</source>
-        <translation>Heslo může mít délku nejvýše %1 znaků</translation>
-    </message>
-    <message>
-        <source>Password can only contain English letters (case-sensitive), numbers or special symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
-        <translation>Heslo může obsahovat pouze písmena z anglické abecedy (rozlišují se malá a VELKÁ písmena), číslice a dále ještě speciální symboly (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</translation>
-    </message>
-    <message>
-        <source>No more than %1 palindrome characters please</source>
-        <translation>Ne více než %1 znaků, které se tam i zpět čtou stejně (palindrom)</translation>
-    </message>
-    <message>
-        <source>No more than %1 monotonic characters please</source>
-        <translation>Ne více než %1 v abecedě po sobě jdoucí znaky prosím</translation>
-    </message>
-    <message>
-        <source>No more than %1 repeating characters please</source>
-        <translation>Ne více než %1 opakující se znaky prosím</translation>
-    </message>
-    <message>
-        <source>Password must contain uppercase letters, lowercase letters, numbers and symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
-        <translation>Je třeba, aby heslo obsahovalo velká a malá písmena z (pouze z anglické abecedy), číslice a symboly (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</translation>
-    </message>
-    <message>
-        <source>Password must not contain more than 4 palindrome characters</source>
-        <translation>Heslo nemůže obsahovat posloupnost více než 4 znaků, která se čte stejně oběma směry (palindrom)</translation>
-    </message>
-    <message>
-        <source>Do not use common words and combinations as password</source>
-        <translation>Jako heslo nepoužívejte běžná slova a jejich kombinace</translation>
-    </message>
-    <message>
-        <source>Create a strong password please</source>
-        <translation>Vytvořte si odolné heslo, prosím</translation>
-    </message>
-    <message>
-        <source>It does not meet password rules</source>
-        <translation>Nesplňuje pravidla pro hesla</translation>
+        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
+        <translation>Zapnuli jste vysokou úroveň zabezpečení systému, proto není možné se přepnout do režimu Wayland. Vypněte vysoký stupeň zabezpečení v Centru zabezpečení a zkuste to znovu.</translation>
     </message>
 </context>
 <context>
@@ -409,13 +325,21 @@
         <source>Log out</source>
         <translation>Odhlásit se</translation>
     </message>
+    <message>
+        <source>Switch user</source>
+        <translation>Přepnout uživatele</translation>
+    </message>
     <message>
         <source>Switch system</source>
         <translation>Přepnout systém</translation>
     </message>
     <message>
-        <source>Switch user</source>
-        <translation>Přepnout uživatele</translation>
+        <source>Update and Shut Down</source>
+        <translation>Aktualizovat a vypnout</translation>
+    </message>
+    <message>
+        <source>Update and Reboot</source>
+        <translation>Aktualizovat a restartovat</translation>
     </message>
 </context>
 <context>
@@ -426,25 +350,52 @@
     </message>
 </context>
 <context>
-    <name>UserListPopupWidget</name>
+    <name>UdcpMFALoginWidget</name>
     <message>
-        <source>Standard User</source>
-        <translation>Běžný uživatel</translation>
+        <source>发送验证码</source>
+        <translation>CAPTCHA</translation>
     </message>
     <message>
-        <source>Administrator</source>
-        <translation>Správce</translation>
+        <source>请输入手机号</source>
+        <translation>Zadejte prosím číslo svého mobilního telefonu</translation>
     </message>
     <message>
-        <source>Other Users</source>
-        <translation type="unfinished"/>
+        <source>请输入验证码</source>
+        <translation>Zadejte prosím ověřovací kód</translation>
+    </message>
+    <message>
+        <source>获取验证码</source>
+        <translation>Získat CAPTCHA</translation>
     </message>
 </context>
 <context>
-    <name>VirtualKeyboardModule</name>
+    <name>UpdateWorker</name>
     <message>
-        <source>Onboard</source>
-        <translation>Na základní desce</translation>
+        <source>Update</source>
+        <translation>Aktualizovat</translation>
+    </message>
+    <message>
+        <source>Please plug in and then install updates.</source>
+        <translation>Připojte se a nainstalujte aktualizace.</translation>
+    </message>
+</context>
+<context>
+    <name>UsersWithTheSameName</name>
+    <message>
+        <source>Return</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Please select the account for login</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Local Account</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Domain Account</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -455,7 +406,7 @@
     </message>
     <message>
         <source>To close the program, click Cancel, and then close the program.</source>
-        <translation>Pro zavření programu klepněte na Zrušit a potom program zavřete.</translation>
+        <translation>Pro zavření programu klikněte na Zrušit a potom program zavřete.</translation>
     </message>
     <message>
         <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
@@ -505,6 +456,33 @@
         <source>Are you sure you want to log out?</source>
         <translation>Opravdu se chcete odhlásit?</translation>
     </message>
+    <message>
+        <source>Update and Shut Down</source>
+        <translation>Aktualizovat a vypnout</translation>
+    </message>
+    <message>
+        <source>Update and Reboot</source>
+        <translation>Aktualizovat a restartovat</translation>
+    </message>
+    <message>
+        <source>Closing the programs and shutting down, please wait...</source>
+        <translation>Zavírání aplikací a vypínání – vyčkejte…</translation>
+    </message>
+    <message>
+        <source>Closing the programs and rebooting, please wait...</source>
+        <translation>Zavírání aplikací a restartování – vyčkejte…</translation>
+    </message>
+    <message>
+        <source>Closing the programs and logging out, please wait...</source>
+        <translation>Zavírání aplikací a odhlašování – vyčkejte…</translation>
+    </message>
+</context>
+<context>
+    <name>dss::module::AssistLoginWidget</name>
+    <message>
+        <source>Automatic login</source>
+        <translation>Automatické přihlášení</translation>
+    </message>
 </context>
 <context>
     <name>dss::module::NetworkModule</name>
